/*
    Document   : dash_plugin_2x5_news.js
    Created on : Aug 29, 2013, 21:26:23 PM
    Author     : Artur Barseghyan (artur.barseghyan@gmail.com)
    Description:
        News plugin specific scripts for django-dash.
*/
;
